# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

ENVIRONMENT_VARIABLES = [
    "APPVEYOR_API_URL",
    "APPVEYOR_ACCOUNT_NAME",
    "APPVEYOR_PROJECT_ID",
    "APPVEYOR_PROJECT_NAME",
    "APPVEYOR_PROJECT_SLUG",
    "APPVEYOR_BUILD_FOLDER",
    "APPVEYOR_BUILD_ID",
    "APPVEYOR_BUILD_NUMBER",
    "APPVEYOR_BUILD_VERSION",
    "APPVEYOR_PULL_REQUEST_NUMBER",
    "APPVEYOR_PULL_REQUEST_TITLE",
    "APPVEYOR_JOB_ID",
    "APPVEYOR_JOB_NAME",
    "APPVEYOR_REPO_PROVIDER",
    "APPVEYOR_REPO_SCM",
    "APPVEYOR_REPO_NAME",
    "APPVEYOR_REPO_BRANCH",
    "APPVEYOR_REPO_TAG",
    "APPVEYOR_REPO_TAG_NAME",
    "APPVEYOR_REPO_COMMIT",
    "APPVEYOR_REPO_COMMIT_AUTHOR",
    "APPVEYOR_REPO_COMMIT_AUTHOR_EMAIL",
    "APPVEYOR_REPO_COMMIT_TIMESTAMP",
    "APPVEYOR_REPO_COMMIT_MESSAGE",
    "APPVEYOR_REPO_COMMIT_MESSAGE_EXTENDED",
    "APPVEYOR_SCHEDULED_BUILD",
    "APPVEYOR_FORCED_BUILD",
    "APPVEYOR_RE_BUILD",
    "PLATFORM",
    "CONFIGURATION",
]
